mod_markdown
============

[![Build Status](https://travis-ci.org/hamano/apache-mod-markdown.svg?branch=master)](https://travis-ci.org/hamano/apache-mod-markdown)

mod_markdown is Markdown filter module for Apache HTTPD Server.

## Dependencies

* discount

  http://www.pell.portland.or.us/~orc/Code/discount/

For Debian/Ubuntu:

~~~
# apt install build-essential libtool automake autoconf
# apt install libmarkdown2-dev apache2 apache2-dev
~~~

## Build

~~~
% autoreconf -f -i
% ./configure --with-apxs=<APXS_PATH> --with-discount=<DISCOUNT_DIR>
% make
% make install
~~~

Note: `<DISCOUNT_DIR>` is the directory that contains the include directory that contains mkdio.h
Probably you need to specify --with-discount=/usr or --with-discount=/usr/local

## Configuration
in httpd.conf:

~~~
LoadModule markdown_module modules/mod_markdown.so
~~~

You need to specify full path on debian or ubuntu.
~~~
LoadModule markdown_module /usr/lib/apache2/modules/mod_markdown.so
~~~

~~~
<Location />
    AddHandler markdown .md

    # If you want to use stylesheet.
    # MarkdownCss style.css
    # MarkdownHeaderHtml "<p>Header</p>"
    # MarkdownFooterHtml "<p>Footer</p>"
</Location>
~~~

Or:

~~~
<Directory /var/www>
    AddHandler markdown .md
    DirectoryIndex index.md
</Directory>
~~~

### MarkdownFlags

default: MKD_TOC | MKD_AUTOLINK | MKD_FENCEDCODE

Flag | Value | Description
--- | --- | ---
MKD_FENCEDCODE   | 0x02000000 | enabled fenced code blocks
MKD_AUTOLINK     | 0x00004000 | make http://foo.com link even without &lt;&gt;s
MKD_TOC          | 0x00001000 | do table-of-contents processing
 |  |
MKD_1_COMPAT     | 0x00002000 | compatibility with MarkdownTest_1.0
MKD_CDATA        | 0x00000080 | generate code for xml ![CDATA[...]]
MKD_EMBED       MKD_NOLINKS|MKD_NOIMAGE|MKD_TAGTEXT
MKD_EXPLICITLIST  | 0x80000000 |        don't combine numbered/bulletted lists
MKD_EXTRA_FOOTNOTE  | 0x00200000 |      enable markdown extra-style footnotes
MKD_GITHUBTAGS   | 0x08000000 | allow dash and underscore in element names
MKD_IDANCHOR     | 0x04000000 | use id= anchors for TOC links
MKD_LATEX        | 0x40000000 | handle embedded LaTeX escapes
MKD_NOALPHALIST  | 0x00080000 | forbid alphabetic lists
MKD_NODIVQUOTE   | 0x00040000 | forbid >%class% blocks
MKD_NODLDISCOUNT  | 0x00800000 |        disable discount-style definition lists
MKD_NODLIST      | 0x00100000 | forbid definition lists
MKD_NO_EXT       | 0x00000040 | don't allow pseudo-protocols
MKD_NOHEADER     | 0x00010000 | don't process header blocks
MKD_NOHTML       | 0x00000008 | don't allow raw html through AT ALL
MKD_NOIMAGE      | 0x00000002 | don't do image processing, block &lt;img&gt;
MKD_NOLINKS      | 0x00000001 | don't do link processing, block &lt;a&gt; tags
MKD_NOPANTS      | 0x00000004 | don't run smartypants()
MKD_NORELAXED    | 0x00000200 | emphasis happens /everywhere/
MKD_NOSTRIKETHROUGH  | 0x00000800 |     forbid ~~strikethrough~~
MKD_NOSTYLE      | 0x00400000 | don't extract &lt;style&gt; blocks
MKD_NOSUPERSCRIPT  | 0x00000100 |       no A^B
MKD_NOTABLES     | 0x00000400 | disallow tables
MKD_SAFELINK     | 0x00008000 | paranoid check for link protocol
MKD_STRICT       | 0x00000010 | disable SUPERSCRIPT, RELAXED_EMPHASIS
MKD_TABSTOP      | 0x00020000 | expand tabs to 4 spaces
MKD_TAGTEXT      | 0x00000020 | process text inside an html tag; no
MKD_URLENCODEDANCHOR  | 0x10000000 | urlencode non-identifier chars instead of replacing with dots

### Custom HTML
mod_markdown will output default document wrappers around the markdown HTML that is generated.  You may adjust this using 
one of two methods.  Firstly, you may wish to simply insert an extra chunk of code to the existing output by utilising the 
MarkdownHeaderHtml and MarkdownFooterHtml options.  (eg, "<hr>THIS IS A DOCUMENTATION ONLY SITE</b>").  

Alternatively, you may wish to completely replace the default document wrapper, though by doing so you alone are completely 
responsible for making the output valid.  MarkdownHeaderFile and MarkdownFooterFile both need to be specified and point to a 
valid file that your webserver can read.  For security, these two options may only be set within *.conf files and may not be 
used within .htaccess (this prevents rogue code from updating a .htaccess to provide access to files it should not).

